@@ -72,6 +72,15 @@ ddxBeforeReset(void)
 {
     return;
 }
+#endif
+
+#if INPUTTHREAD
+/** This function is called in Xserver/os/inputthread.c when starting
+    the input thread. */
+void
+ddxInputThreadInit(void)
+{
+}
 #endif
 
  _X_NORETURN
